# moebelgruppe Kompositum.py
# Fortsetzung der Entwicklung auf eine Moebelgruppe hin
# Umsetzen des Kompositummusters
# _aktualisiereAbmessungen findet hier statt
# AendereBreite und AendereTiefe deaktiviert

from grafikfenster import *

from moebel import Moebel

### ---------------------------------------------------
class Moebelgruppe(Moebel):
    '''Die Klasse Moebelgruppe ist die Oberklasse.
    Begonnen wird mit einer leeren Moebelgruppe.
    Umsetzung des Kompositummusters in Transformiere von Moebel.'''
    def __init__(self,
                 xPos=50,
                 yPos=150,
                 winkel=0,
                 farbe="",
                 sichtbar=False):
        self.__moebel=[]
        Moebel.__init__(self, xPos, yPos, 0, 0, winkel, farbe, sichtbar)

    def GibAlle(self):
        return self.__moebel

    def LoescheAlle(self):
        for moebel in []+self.__moebel: # echte Kopie
            self.Entferne(moebel)
            del(moebel)
        
    def GibFigur(self):
        """definiert die zu zeichnende Figur"""
        path = self.GibZeichenPfad()

        for moebel in self.__moebel:
            path.AddPath(moebel.GibFigur())

        return self.Transformiere(path)

    def FuegeHinzu(self, moebel):
        '''Die Sichtbarkeit des Moebel-Objekts wird
        auf die Sichtbarkeit der Gruppe gesetzt'''
        if moebel in self.__moebel: return
        self.__moebel.append(moebel)
        moebel.SetzeGruppe(self)
        self._AktualisiereAbmessungen()
        if self.GibSichtbar(): moebel.Zeige()
        else: moebel.Verberge()
        self.Update()
    
    def Entferne(self, moebel):
        '''Die Sichtbarkeit des Moebel-Objekts wird auf False gesetzt.
        Ob das sinnvoll ist, haengt von der konkreten Anwendung ab.'''
        if moebel not in self.__moebel: return
        moebel.Verberge()
        self.__moebel.remove(moebel)
        moebel.SetzeGruppe(None)
        self._AktualisiereAbmessungen()
        self.Update()
    
    def _AktualisiereAbmessungen(self):
        """setzt breite und tiefe neu"""
        # Figur darf fuer GetBox nicht gedreht sein, daher
        winkel=self.GibOrientierung()
        self.Drehe(-winkel)
        daten=self.GibFigur().GetBox().Get()
        self.Drehe(winkel)
        super().AendereBreite(int(daten[2])-2)
        super().AendereTiefe(int(daten[3])-2)
    
    def AendereBreite(self, neueBreite):
        '''wird von _AktualisiereAbmessungen in Moebel erledigt'''
        pass
        
    def AendereTiefe(self, neueTiefe):
        '''wird von _AktualisiereAbmessungen in Moebel erledigt'''
        pass
        
    def Update(self):
        """Update-Methode"""
        for moebel in self.__moebel:
            moebel.Update()

    ### Ergaenzung:
    def AendereFarbe(self, farbe):
        '''Nur begrenzt sinnvoll: Es wird eine gemeinsame Farbe
        fuer alle beteiligten Moebelobjekte erzwungen.'''
        super(Moebelgruppe,self).AendereFarbe(farbe)
        for moebel in self.__moebel:
            moebel.AendereFarbe(farbe)

### ---------------------------------------------------
class MoebelgruppeApp(wx.App):
    def OnInit(self):
        self.fenster = GrafikFenster(None, "Raumplaner-Grafik")
        self.SetTopWindow(self.fenster)
        self.fenster.Show(True)
        self.fenster.panel.Refresh()
        self.fenster.ZeigeShellFrame()
        ##self.TestAnwendung()
        #self.fenster.ZeigeFillingFrame()
        return True
        
### ---------------------------------------------------
if __name__ == '__main__':
    app = MoebelgruppeApp(redirect=False)
    # Parameterwert True, wenn Ausgaben in der Standard E/A angezeigt werden sollen
    app.MainLoop()
