# tischgruppe Kompositum.py
# Fortsetzung der Entwicklung auf eine Tischgruppe
# mit den Methoden FuegeHinzu() und Entferne()
# und mit _AktualisiereAbmessungen() in Moebel

# Umsetzen des Kompositummusters

from grafikfenster import *

from moebelgruppe import Moebelgruppe
from tisch import Tisch
from stuhl import Stuhl

### ---------------------------------------------------
class Tischgruppe(Moebelgruppe):
    '''Die Klasse Tischgruppe erzeugt automatisch die Objekte,
    ein Tischobjekt und mehrere Stuhlobjekte.
    Begonnen wird mit einer leeren Tischgruppe, der durch
    Konfigurieren die notwendigen Teile definiert werden.
    Umsetzung des Kompositummusters in Transformiere von Moebel.'''
    def __init__(self,
                 xPos=50,
                 yPos=50,
                 winkel=0,
                 farbe="",
                 sichtbar=False):
        Moebelgruppe.__init__(self, xPos, yPos, winkel, farbe, sichtbar)
        self.__stuehle_inBreite,self.__stuehle_inTiefe = 0,0
        self.SetzeStuehle(0,0)
        # Stuhlabstand statisch 10

    def SetzeStuehle(self, inBreite=2, inTiefe=1):
        '''setzt die Anzahl der Stuehle an der einen Kante
        und der anderen Kante'''
        self.__stuehle_inBreite,self.__stuehle_inTiefe = inBreite,inTiefe
        self.ErzeugeTischgruppe()
        
    def ErzeugeTischgruppe(self):
        """die Tischgruppe wird neu erzeugt"""
        if 0 in [self.__stuehle_inBreite,self.__stuehle_inTiefe]: return
        self.LoescheAlle()
        stuhl1=Stuhl(0,0,winkel=270) # am Kopf
        tischBreite=10+self.__stuehle_inBreite*(stuhl1.GibBreite()+10)
        tischTiefe=10+self.__stuehle_inTiefe*(stuhl1.GibTiefe()+10)
        dX_und_Y=stuhl1.GibTiefe()+10
        stuhl1.BewegeVertikal(dX_und_Y+10)
        self.FuegeHinzu(Tisch(dX_und_Y,dX_und_Y,tischBreite,tischTiefe))
        self.FuegeHinzu(stuhl1)
        for i in range(self.__stuehle_inBreite):
            self.FuegeHinzu(Stuhl(dX_und_Y+10+i*(stuhl1.GibBreite()+10),0,winkel=0))
            self.FuegeHinzu(Stuhl(dX_und_Y+10+i*(stuhl1.GibBreite()+10),
                                  dX_und_Y+10+tischTiefe,winkel=180))
        for i in range(self.__stuehle_inTiefe):
            if i>0: # ersten nicht doppelt
                self.FuegeHinzu(Stuhl(0,dX_und_Y+10+i*(stuhl1.GibTiefe()+10),winkel=270))
            self.FuegeHinzu(Stuhl(dX_und_Y+10+tischBreite,
                                  dX_und_Y+10+i*(stuhl1.GibTiefe()+10),
                                  winkel=90))

### ---------------------------------------------------
class TischgruppeApp(wx.App):
    def OnInit(self):
        self.fenster = GrafikFenster(None, "Raumplaner-Grafik")
        self.SetTopWindow(self.fenster)
        self.fenster.Show(True)
        self.fenster.panel.Refresh()
        self.fenster.ZeigeShellFrame()
        ##self.TestAnwendung1()
        #self.fenster.ZeigeFillingFrame()
        return True

        
    def TestAnwendung1(self):        
        global tg
        print('global: tg\ntg mit sechs Stühlen')
        try:
            tg.LoescheAlle()
        except Exception as e:
            tg=Tischgruppe(sichtbar=True)
        tg.SetzeStuehle()

    def TestAnwendung2(self):
        global tg
        print('global: tg\nAbmessungen 3x2, 10 Stühle')
        try:
            tg.LoescheAlle()
        except Exception as e:
            tg=Tischgruppe(sichtbar=True)
        tg.SetzeStuehle(3,2)

### ---------------------------------------------------
if __name__ == '__main__':
    app = TischgruppeApp(redirect=False)
    # Parameterwert True, wenn Ausgaben in der Standard E/A angezeigt werden sollen
    app.MainLoop()
